#!/bin/bash

#     Copyright (C) 2009 Michael Verret <michael.verret@gmail.com>
#
#            This script is released under the terms of the:
#                      GNU GENERAL PUBLIC LICENSE
#                        Version 3, 29 June 2007
#                http://www.gnu.org/licenses/gpl-3.0.txt
#
# This is a Bash shell script written to automate the process of
# generating software packages suitable for use with Zenwalk Linux.
#
# Zenwalk Linux is a GNU/Linux operating system.
#
#              For more information on Zenwalk Linux visit:
#                        http://www.zenwalk.org/
#
# Bash is a free software Unix shell written for the GNU Project.
#
#                   For more information on Bash visit:
#           http://tiswww.case.edu/php/chet/bash/bashtop.html


# Package variables:
#_______________________________________________________________________
Summary="X11 video drivers metapackage"
Package_Name="xorg-drivers-video"
Package_Version="7.4"
Package_Arch="noarch"
Package_Release="62"
Package_Build="2"
File_Image=" "
File_Misc=" \
	gpl-3.0.txt.gz"
File_Patch=" "
File_Script=" \
	build-${Package_Name}.sh"
Special_Docs=" "
Desc_Line_00=": (${Summary})"
Desc_Line_01=":"
Desc_Line_02=": This metapackage provides the necessary display drivers"
Desc_Line_03=": for the X.Org X Window System."
Desc_Line_04=":"
Desc_Line_05=":"
Desc_Line_06=":"
Desc_Line_07=":"
Desc_Line_08=":"
Desc_Line_09=":"
Desc_Line_10=":"
# BuildRequires: 
# Requires:


# Constant variables:
#_______________________________________________________________________
Build_Root=$(pwd)
Package_Duo="${Package_Name}-${Package_Version}"
Package_Title="${Package_Duo}-${Package_Arch}-${Package_Release}.${Package_Build}"
Package_Root="${Build_Root}/${Package_Title}"


# Build & install:
#_______________________________________________________________________
if [ -d ${Package_Name}-${Package_Version}-${Package_Arch} ] ; then
	rm -rf ${Package_Name}-${Package_Version}-${Package_Arch}
fi
for Each in ${Package_Title}.dep ${Package_Title}.md5 ${Package_Title}.src.md5 \
	${Package_Title}.src.tbz ${Package_Title}.tgz ; do
	if [ -e ${Each} ] ; then
		rm -rf ${Each}
	fi
done

mkdir -p ${Package_Root}/usr/doc/${Package_Duo}/
zcat ${Build_Root}/gpl-3.0.txt.gz > ${Package_Root}/usr/doc/${Package_Duo}/COPYING

cat <<EOF0 > ${Build_Root}/${Package_Title}.dep
xorg-driver-apm,xorg-driver-ark,xorg-driver-ast,xorg-driver-ati,xorg-driver-avivo,xorg-driver-chips,xorg-driver-cirrus,xorg-driver-dummy,xorg-driver-fbdev,xorg-driver-geode,xorg-driver-glint,xorg-driver-i128,xorg-driver-i740,xorg-driver-intel,xorg-driver-mach64,xorg-driver-mga,xorg-driver-neomagic,xorg-driver-newport,xorg-driver-nouveau,xorg-driver-nv,xorg-driver-openchrome,xorg-driver-r128,xorg-driver-radeonhd,xorg-driver-rendition,xorg-driver-s3,xorg-driver-s3virge,xorg-driver-savage,xorg-driver-siliconmotion,xorg-driver-sis,xorg-driver-sisusb,xorg-driver-tdfx,xorg-driver-tga,xorg-driver-trident,xorg-driver-tseng,xorg-driver-v4l,xorg-driver-vesa,xorg-driver-vmware,xorg-driver-voodoo
EOF0


# Complete the final packaging routines:
#_______________________________________________________________________
mkdir ${Package_Root}/install
cat <<EOF1 > ${Package_Root}/install/slack-desc
${Package_Name}${Desc_Line_00}
${Package_Name}${Desc_Line_01}
${Package_Name}${Desc_Line_02}
${Package_Name}${Desc_Line_03}
${Package_Name}${Desc_Line_04}
${Package_Name}${Desc_Line_05}
${Package_Name}${Desc_Line_06}
${Package_Name}${Desc_Line_07}
${Package_Name}${Desc_Line_08}
${Package_Name}${Desc_Line_09}
${Package_Name}${Desc_Line_10}
EOF1

mkdir -p ${Package_Root}/usr/src/${Package_Duo}
cd ${Build_Root}
cp ${File_Misc} ${File_Script} ${Package_Root}/usr/src/${Package_Duo}

( cd ${Package_Root}
	makepkg -l y -c n ${Build_Root}/${Package_Title}.tgz
)
cd ${Build_Root}
md5sum ${Package_Title}.tgz > ${Package_Title}.md5
rm -rf ${Package_Root}

mkdir -p ${Package_Root}.src
cp ${File_Misc} ${File_Script} ${Package_Root}.src
tar -jcf ${Package_Title}.src.tbz ${Package_Title}.src
rm -rf ${Package_Title}.src 
md5sum ${Package_Title}.src.tbz > ${Package_Title}.src.md5


# Changelog of script edits:
#_______________________________________________________________________


# ~ Date: 		Fri Mar 13th 2009
# ~ Editor:		Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Changes:	(Rebuilt over gcc-4.3.3)

# ~ Date: 		Tue Feb 24th 2009
# ~ Editor:		Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Changes:	n/a (Original script creation)
